@@ -629,17 +629,19 @@ void MH_NodePairedTiesToggles (MHproposal *MHp, Network *nwp) {
 *********************/
 void MH_OneRandomTnTNode (MHproposal *MHp, Network *nwp) {  
   Vertex tail=0, head, e, head1;
-  int noutedge=0, ninedge=0, k0=0, ndyad, fvalid=0, k;
+  int noutedge=0, ninedge=0, k0=0, fvalid=0, k; // Deleted ndyad
 
   /* *** don't forget tail-> head now */
   
+  /* Disabled
   if ( nwp->directed_flag )
     {
       ndyad = (nwp->nnodes - 1) * nwp->nnodes;
     }else{
       ndyad = (nwp->nnodes - 1) * nwp->nnodes / 2;
     }
-  
+  */
+ 
   fvalid=0;
   while(fvalid==0){
     
